AtSignLogger class

Class for AtSignLogger Implementation

Constructors

AtSignLogger(String name, {LoggingHandler? loggingHandler})
The AtSignLogger is a wrapper on the Logger to log events.

Properties

hashCode → int
The hash code for this object.
no setterinherited
hierarchicalLoggingEnabled ↔ bool
getter/setter pair
level ↔ String?
getter/setter pair
logger ↔ Logger
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

finer(Object? message, [Object? error, StackTrace? stackTrace]) → void
finest(Object? message, [Object? error, StackTrace? stackTrace]) → void
info(Object? message, [Object? error, StackTrace? stackTrace]) → void
isLoggable(String value) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
severe(Object? message, [Object? error, StackTrace? stackTrace]) → void
shout(Object? message, [Object? error, StackTrace? stackTrace]) → void
toString() → String
A string representation of this object.
inherited
warning(Object? message, [Object? error, StackTrace? stackTrace]) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

consoleLoggingHandler → ConsoleLoggingHandler
final
defaultLoggingHandler ↔ LoggingHandler
The default logging handler to log events.
getter/setter pair
root_level ↔ String
getter/setter pair
stdErrLoggingHandler → StdErrLoggingHandler
final