FileLoggingHandler class
Appends log messages to a file in pipe-delimited format.
Format: LEVEL|timestamp|loggerName|message
Usage
var logger = AtSignLogger('MyApp');
logger.loggingHandler = FileLoggingHandler('app.log');
- Implemented types
Constructors
- FileLoggingHandler(String filename)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
LogRecord record) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited